@@ -1,3 +1,6 @@
+from PIL import Image
+import cv2
+
 def add(num1 , num2):
 	return num1 + num2
 
@@ -135,4 +138,17 @@ def compound_interest(p, t, r):
 
 def mon_emi(p, r, n):
 	return p * r * ((1+r)**n)/((1+r)**n - 1)
-	print("Tip - Use interest rate per month instead of interest rate per annum(It will show a wrong answer)")
+
+def jpg_png(path: str , output: str = "output.png"):
+    iml = Image.open(path)
+    iml.save(output)
+
+    return None
+
+def im_border(path: str, output: str = "output.png"):
+              im1 = cv2.imread(path)
+              border = cv2.copyMakeBorder(
+                            im1, 20, 20, 20, 20, cv2.BORDER_CONSTANT, value = [128, 128, 128])
+              cv2.imwrite(output, border)
+
+              return None 
